@@ -121,6 +121,9 @@ ghex_window_close(GHexWindow *win)
 		gtk_widget_set_sensitive(converter_get, FALSE);
 
     gtk_widget_destroy(GTK_WIDGET(win));
+
+    if (doc->views == NULL) /* If we have destroyed the last view */
+      g_object_unref (G_OBJECT (doc));
 }
 
 static gboolean 
@@ -790,8 +793,12 @@ ghex_window_get_ui_component(GHexWindow *win)
 void
 ghex_window_set_doc_name(GHexWindow *win, const gchar *name)
 {
-    gchar *title = g_strdup_printf(_("GHex - %s"), name);
-    gtk_window_set_title(GTK_WINDOW(win), title);
+    if(name != NULL) {
+        gchar *title = g_strdup_printf(_("GHex - %s"), name);
+        gtk_window_set_title(GTK_WINDOW(win), title);
+        g_free(title);
+    }
+    else gtk_window_set_title(GTK_WINDOW(win), _("GHex"));
 }
 
 struct _MessageInfo {
